@@ -29,7 +29,9 @@
 #include "baumbrl.h"
 #include "alvabrl.h"
 #include "handybrl.h"
-#ifdef __BRLTTY_SUPPORT__
+#include "ecobrl.h"
+
+#ifdef BRLTTY_SUPPORT
 #include "ttybrl.h"
 #endif
 
@@ -45,6 +47,7 @@ BRLDevInfo   supported_devices[] = {
   {"VARIO20", "BAUM VARIO - 20 cells"},
   {"VARIO40", "BAUM VARIO - 40 cells"},
   {"VARIO80", "BAUM VARIO - 80 cells"},
+  {"PRONTO",  "BAUM PRONTO - 18 cells"},
   {"DM80P",   "BAUM DM80 - 80 cells"},
   {"INKA",    "BAUM INKA"},
   {"ALVA320", "ALVABRAILLE 320"},
@@ -60,7 +63,10 @@ BRLDevInfo   supported_devices[] = {
   {"HTBS8",   "HandyTech Braille Star 80"},
   {"HTMB2",   "HandyTech Modular 24"},
   {"HTMB4",   "HandyTech Modular 44"},
-  {"HTMB8",   "HandyTech Modular 84"}
+  {"HTMB8",   "HandyTech Modular 84"},
+  {"ECO20",   "EcoBraille 20"},
+  {"ECO40",   "EcoBraille 40"},
+  {"ECO80",   "EcoBraille 80"}
 
  };
 
@@ -133,6 +139,7 @@ brl_open_device (gchar        *device_name,
 	    strcmp("VARIO40", device_name) == 0 ||
 	    strcmp("VARIO20", device_name) == 0 ||
 	    strcmp("VARIO80", device_name) == 0 ||
+	    strcmp("PRONTO", device_name) == 0 ||
 	    strcmp("DM80P", device_name) == 0 ||
 	    strcmp("INKA", device_name) == 0)
 	{
@@ -152,7 +159,7 @@ brl_open_device (gchar        *device_name,
 	else if (strcmp("BRLTTY", device_name) == 0)
 	{			
 	    rv = 0;
-#ifdef __BRLTTY_SUPPORT__		
+#ifdef BRLTTY_SUPPORT
 	    rv = brltty_brl_open_device (device_name, port, device_callback, current_device);			
 #endif
 	}
@@ -172,6 +179,12 @@ brl_open_device (gchar        *device_name,
 	{
 	    rv =  handy_brl_open_device(device_name, port, device_callback, current_device);
 	}
+	else if (strcmp("ECO20", device_name) == 0 ||
+		 strcmp("ECO40", device_name) == 0 ||
+		 strcmp("ECO80", device_name) == 0 )
+	{
+	    rv =  eco_brl_open_device(device_name, port, device_callback, current_device);
+	}
 
 	else
 	{
