@@ -100,7 +100,7 @@ brltty_brl_send_dots (guchar 	*dots,
 	memset (&sendbuff[count], 0, len-count);
     }
 
-    ws.attrOr = dots;
+    ws.attrOr = sendbuff;
     if (brlapi_write(&ws) == 0) 
 	return 1;
     else 
@@ -234,13 +234,13 @@ brltty_brl_open_device (gchar* 			device_name,
 
     if ((fd = brlapi_initializeConnection (NULL, NULL)) < 0) 
     {
-	fprintf(stderr, "Error opening brlapi connection");
+	brlapi_perror("Error opening brlapi connection");
 	return 0;
     }
 
     if (brlapi_getDisplaySize (&dd.x, &dd.y) != 0) 
     {
-	fprintf(stderr, "Unable to get display size");
+	brlapi_perror("Unable to get display size");
 	return 0;
     }
 
