@@ -96,6 +96,9 @@ src_present_real_sro_for_brl_and_brlmon (SRObject *obj, gchar *reason)
 
     srl_assert (src_use_braille || src_use_braille_monitor);
 
+    if ((src_use_speech || src_use_magnifier) && srl_is_object_watched (obj))
+	return;
+
 	src_caret_position = -1;
     src_enable_format_string = FALSE; 
     txt = src_presentation_sro_get_pres_for_device (obj, reason, "braille");
@@ -261,8 +264,8 @@ src_present_real_sro_for_speech (SRObject *obj, gchar *reason)
 	    if (srl_is_object_focused (obj) || strcmp (reason, "present") == 0 ||
 		strcmp (reason, "object:context-switched") == 0)
 	    {
-		if ( role == SR_ROLE_STATUS_BAR && strcmp (reason , "focus:") == 0)
-		    src_speech_send_chunk (txt, SRC_SPEECH_PRIORITY_SYSTEM, TRUE);
+		if (role == SR_ROLE_STATUS_BAR && strcmp (reason , "focus:") == 0)
+		    src_speech_send_chunk (txt, SRC_SPEECH_PRIORITY_WARNING, TRUE);
 		else if ((role == SR_ROLE_TABLE || role == SR_ROLE_TREE_TABLE) &&
 			strcmp (reason , "focus:") == 0)
 		    src_speech_send_chunk (txt, SRC_SPEECH_PRIORITY_IDLE, FALSE);
@@ -290,6 +293,9 @@ src_present_real_sro_for_magnifier (SRObject *obj, gchar *reason)
 
     srl_assert (src_use_magnifier);
 
+    if (src_use_speech && srl_is_object_watched (obj))
+	return;
+
     txt = src_presentation_sro_get_pres_for_device (obj, reason, "magnifier");
     if (txt)
     {
@@ -387,6 +393,8 @@ src_present_crt_window ()
 		src_speech_send_chunk (txt, SRC_SPEECH_PRIORITY_WARNING, FALSE);
 	    else if (strcmp (reason, "window:rename") == 0)
 		src_speech_send_chunk (txt, SRC_SPEECH_PRIORITY_LOW, TRUE);
+	    else if (strcmp (reason, "object:context-switched") == 0)
+	    	src_speech_send_chunk (txt, SRC_SPEECH_PRIORITY_WARNING, FALSE);
 	    else
 		src_speech_send_chunk (txt, SRC_SPEECH_PRIORITY_SYSTEM, TRUE);
 	}
@@ -1686,6 +1694,16 @@ src_process_modifier (gchar *modifier)
 	    part1 = _("shift");
 	    pos = 6;
         }
+	else if (strncmp (modifier, "Super", 5) == 0)
+	{
+	    part1 = _("Window");
+	    pos = 6;
+        }	
+	else if (strncmp (modifier, "Hyper", 5) == 0)
+	{
+	    part1 = _("Menu");
+	    pos = 6;
+        }	
 	else if (strncmp (modifier, "Caps", 3) == 0)
 	{
 	    part1 = _("caps lock");
@@ -1757,6 +1775,8 @@ src_process_cursor (gchar *cursor)
 	    src_last_cursor_echo = g_strdup (_("delete"));
 	else if (strcmp (cursor, "Escape") == 0)
 	    src_last_cursor_echo = g_strdup (_("escape"));	    
+	else if (strcmp (cursor, "Menu") == 0)
+	    src_last_cursor_echo = g_strdup (_("Menu"));
 	else
 	    sru_assert_not_reached ();
 	        
@@ -1798,7 +1818,9 @@ src_process_key (SREvent *event,
 	strncmp (srhotkey_data->keystring, "Control", 7) == 0 ||
 	strncmp (srhotkey_data->keystring, "Shift", 5) == 0 ||
 	strncmp (srhotkey_data->keystring, "Caps", 3) == 0 ||
-	strncmp (srhotkey_data->keystring, "Num", 3) == 0)
+	strncmp (srhotkey_data->keystring, "Num", 3) == 0 ||
+	strncmp (srhotkey_data->keystring, "Super", 5) == 0 ||
+	strncmp (srhotkey_data->keystring, "Hyper", 5) == 0)
     {
     
 	src_process_modifier (srhotkey_data->keystring);
@@ -1813,7 +1835,8 @@ src_process_key (SREvent *event,
 	     strcmp (srhotkey_data->keystring, "Up") == 0 ||
 	     strcmp (srhotkey_data->keystring, "BackSpace") == 0 ||
 	     strcmp (srhotkey_data->keystring, "Delete") == 0 ||
-	     strcmp (srhotkey_data->keystring, "Escape") == 0)
+	     strcmp (srhotkey_data->keystring, "Escape") == 0 ||
+	     strcmp (srhotkey_data->keystring, "Menu") == 0)
     {
 	src_process_cursor (srhotkey_data->keystring);
     }
