@@ -518,6 +518,8 @@ gboolean sro_text_get_difference (SRObject *obj, gchar **difference,
 
 gboolean sro_text_get_abs_offset (SRObject *obj, SRLong *offset,
 					    SRLong index);
+gboolean sro_is_word_navigation (SRObject *obj, SRLong crt_offset, 
+                                           SRLong last_offset, SRLong index);					    
 gboolean sro_text_is_same_line (SRObject *obj, SRLong offset,
 					    SRLong index);
 
